@@ -84,7 +84,7 @@
 #define SONNETCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETCORE_NO_DEPRECATED
-#  define SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef SONNETCORE_NO_DEPRECATED_WARNINGS
 #  define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETCORE_DEPRECATED_WARNINGS_SINCE SONNETCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define SONNETCORE_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
