@@ -84,7 +84,7 @@
 #define SONNETUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETUI_NO_DEPRECATED
-#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef SONNETUI_NO_DEPRECATED_WARNINGS
 #  define SONNETUI_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETUI_DEPRECATED_WARNINGS_SINCE SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
